module LiquidAddons
    def add_storyblok_api_key(text)
        text + Rails.application.config.storyblok[:CMS_API_TOKEN]
    end

    def javascript_tag(javascript_file)
        ActionController::Base.helpers.javascript_include_tag(javascript_file)
    end

    def stylesheet_tag(css_file)
        ActionController::Base.helpers.stylesheet_link_tag css_file, :media => "all"
    end

    def prefix_base_url(string)
        Rails.application.config.frontend_api[:base_url] + string
    end

    def current_shop_id(ignore)
        @context.environments.first['story']['slug']
    end
end

Liquid::Template.register_filter(LiquidAddons)


module SkirentalWebFrontend
    class ShopBaseController < ApplicationController
        def portal_page
            # We do not support a portal yet..
            # Only redirect..
            root_url = Rails.application.config.web_base[:ROOT_URL]

            redirect_to root_url
        end

        def show
            response.headers['X-FRAME-OPTIONS'] = 'ALLOWALL'

            client = Storyblok::Client.new(
                logger:         logger,
                cache_version:  Time.now.to_i,
                token:          Rails.application.config.storyblok[:CMS_API_TOKEN],
                version:        Rails.application.config.storyblok[:VERSION]
            )

            @shop_id = params[:shop_id]

            begin
                assigns = {
                    story: client.story(@shop_id.parameterize)['data']['story'],
                }

                # Location of the liquid building blocks..
                Liquid::Template.file_system = Liquid::LocalFileSystem.new("#{SkirentalWebFrontend::Engine.root}/app/views/skirental_web_frontend/shop_base")

                # Location of the liquid layout (base template)
                template = Liquid::Template.parse(File.read("#{SkirentalWebFrontend::Engine.root}/app/views/layouts/skirental_web_frontend/shop_base.liquid"))

                render html: template.render!(assigns.stringify_keys, {}).html_safe
            rescue RestClient::NotFound => e
                Rails.logger.error "Error: Unable to find Shop: #@shop_id (#{e})"
                redirect_to "/#{@shop_id}/reservation"
            end
        end

        def new_session
            reset_session
            render json: { error: "", message: "session reset" }
        end
    end
end
